//! This file has been automatically generated by `objc2`'s `header-translator`.
//! DO NOT EDIT
#[cfg(feature = "AppleUSBDefinitions")]
#[path = "AppleUSBDefinitions.rs"]
mod __AppleUSBDefinitions;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
#[path = "IOUSBHostFamilyDefinitions.rs"]
mod __IOUSBHostFamilyDefinitions;
#[cfg(feature = "IOUSBLib")]
#[path = "IOUSBLib.rs"]
mod __IOUSBLib;
#[cfg(feature = "USB")]
#[path = "USB.rs"]
mod __USB;
#[cfg(feature = "USBSpec")]
#[path = "USBSpec.rs"]
mod __USBSpec;

#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSB20BitrateFull;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSB20BitrateHigh;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSB20BitrateLow;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSB30RetimerDepthLimit;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBAppleVendorID;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBConfigurationDescriptorAttributeRemoteWakeCapable;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBConfigurationDescriptorAttributeSelfPowered;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceFeatureSelectorLTMEnable;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceFeatureSelectorRemoteWakeup;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceFeatureSelectorTestMode;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceFeatureSelectorU1Enable;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceFeatureSelectorU2Enable;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceRequestClearFeature;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceRequestGetConfiguration;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceRequestGetDescriptor;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceRequestGetInterface;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceRequestGetState;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceRequestGetStatus;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceRequestSetAddress;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceRequestSetConfiguration;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceRequestSetDescriptor;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceRequestSetFeature;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceRequestSetInterface;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceRequestSetIsochronousDelay;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceRequestSetSel;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceRequestSynchFrame;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceStatusLTMEnable;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceStatusRemoteWakeEnable;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceStatusSelfPowered;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceStatusU1Enable;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBDeviceStatusU2Enable;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorDirection;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorDirectionIn;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorDirectionOut;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorDirectionPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorEndpointAddressReserved;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorNumber;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorNumberPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorPacketSize;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorPacketSizeMult;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorPacketSizeMultPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorPacketSizePhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorReserved;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorReservedPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorSynchronizationType;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorSynchronizationTypeAdaptive;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorSynchronizationTypeAsynchronous;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorSynchronizationTypeNone;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorSynchronizationTypePhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorSynchronizationTypeSynchronous;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorTransferType;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorTransferTypeBulk;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorTransferTypeControl;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorTransferTypeInterrupt;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorTransferTypeIsochronous;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorTransferTypePhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorUsageType;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorUsageTypeInterruptNotification;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorUsageTypeInterruptPeriodic;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorUsageTypeInterruptReserved1;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorUsageTypeInterruptReserved2;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorUsageTypeIsocData;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorUsageTypeIsocFeedback;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorUsageTypeIsocImplicit;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorUsageTypeIsocReserved;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBEndpointDescriptorUsageTypePhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBHubDelayNs;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBHubPort2PortExitLatencyNs;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBInterfaceFeatureSelectorSuspend;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBInterfaceStatusRemoteWakeCapable;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBInterfaceStatusRemoteWakeEnable;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBInterfaceSuspendLowPower;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBInterfaceSuspendRemoteWakeEnable;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBPingResponseTimeNs;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedDeviceCapability5Gb;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedDeviceCapabilityFullSpeed;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedDeviceCapabilityHighSpeed;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedDeviceCapabilityLTM;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedDeviceCapabilityLowSpeed;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedDeviceCapabilitySupport5Gb;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedDeviceCapabilitySupportFullSpeed;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedDeviceCapabilitySupportHighSpeed;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedDeviceCapabilitySupportLowSpeed;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedDeviceCapabilityU1DevExitLatMax;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedDeviceCapabilityU2DevExitLatMax;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedEndpointCompanionDescriptorBulkMaxStreams;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedEndpointCompanionDescriptorBulkMaxStreamsPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedEndpointCompanionDescriptorBulkReserved;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedEndpointCompanionDescriptorBulkReservedPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedEndpointCompanionDescriptorIsocMult;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedEndpointCompanionDescriptorIsocMultPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedEndpointCompanionDescriptorIsocReserved;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedEndpointCompanionDescriptorIsocReservedPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedEndpointCompanionDescriptorMaxBurst;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedEndpointCompanionDescriptorMaxBurstPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedEndpointCompanionDescriptorSSPIsocCompanion;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedHubCharacteristicsCompoundDevice;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedHubCharacteristicsOverCurrentGlobal;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedHubCharacteristicsOverCurrentIndividual;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedHubCharacteristicsOverCurrentMask;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedHubCharacteristicsPowerSwitchingGanged;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedHubCharacteristicsPowerSwitchingIndividual;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedHubCharacteristicsPowerSwitchingMask;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedHubCharacteristicsReserved;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedHubDecodeLatencyMax;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedHubDelayMax;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilityMinRxLaneCount;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilityMinRxLaneCountPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilityMinTxLaneCount;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilityMinTxLaneCountPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilityReserved;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilityReservedPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkAsymmetric;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkDirection;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkDirectionPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkDirectionRx;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkDirectionTx;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkLSE;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkLSEBits;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkLSEGbits;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkLSEKbits;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkLSEMbits;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkLSEPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkMinSpeedId;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkMinSpeedIdPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkProtocol;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkProtocolPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkReserved;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkReservedPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkSpeedAttrCount;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkSpeedAttrCountPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkSpeedId;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkSpeedIdCount;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkSpeedIdCountPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkSpeedIdPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkSpeedMantissa;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkSpeedMantissaPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkSymmetric;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkSymmetry;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkSymmetryPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkType;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBSuperSpeedPlusDeviceCapabilitySublinkTypePhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBUSB20ExtensionCapabilityBESL;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBUSB20ExtensionCapabilityBESLD;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBUSB20ExtensionCapabilityBESLDPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBUSB20ExtensionCapabilityBESLDValid;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBUSB20ExtensionCapabilityBESLPhase;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBUSB20ExtensionCapabilityBESLSupport;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBUSB20ExtensionCapabilityBESLValid;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::kIOUSBUSB20ExtensionCapabilityLPM;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSB20BusCurrent;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSB30BusCurrent;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSB30DeviceNotificationType;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSB30HubExtStatus;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSB30HubPortStatusCode;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSB30LinkStateTimeout;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSB30ResetTimeout;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSB30TimingParameters;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSBBusVoltage;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSBDescriptorSize;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSBDescriptorType;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSBDeviceCapabilityType;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSBDeviceRequest;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSBDeviceRequestDirectionValue;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSBDeviceRequestRecipientValue;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSBDeviceRequestTypeValue;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSBEndpointDirection;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSBEndpointSynchronizationType;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSBEndpointType;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSBEndpointUsageType;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSBLanguageID;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::tIOUSBTopology;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSB20HubDescriptor;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSB30HubPortStatusExt;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBBOSDescriptor;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBConfigurationDescHeader;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBConfigurationDescriptor;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBDFUDescriptor;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBDescriptor;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBDescriptorHeader;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBDeviceCapabilityBillboard;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBDeviceCapabilityBillboardAltConfig;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBDeviceCapabilityBillboardAltConfigCompatibility;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBDeviceCapabilityBillboardAltMode;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBDeviceCapabilityContainerID;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBDeviceCapabilityDescriptorHeader;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBDeviceCapabilitySuperSpeedPlusUSB;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBDeviceCapabilitySuperSpeedUSB;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBDeviceCapabilityUSB2Extension;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBDeviceDescriptor;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBDeviceQualifierDescriptor;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBDeviceRequest;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBDeviceRequestSetSELData;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBEndpointDescriptor;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBEndpointFeatureSelectorStall;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBEndpointStatusHalt;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBHIDDescriptor;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBHIDReportDesc;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBInterfaceAssociationDescriptor;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBInterfaceDescriptor;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBPlatformCapabilityDescriptor;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBStringDescriptor;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBSuperSpeedEndpointCompanionDescriptor;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBSuperSpeedHubDescriptor;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::IOUSBSuperSpeedPlusIsochronousEndpointCompanionDescriptor;
#[cfg(feature = "AppleUSBDefinitions")]
pub use self::__AppleUSBDefinitions::UASPipeDescriptor;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kAppleCurrentExtra;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kAppleCurrentExtraInSleep;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kAppleMaxPortCurrent;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kAppleMaxPortCurrentInSleep;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kIOUSBBillboardEntitlement;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kIOUSBHostControllerInterfaceEntitlement;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kIOUSBHostDeviceClassName;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kIOUSBHostInterfaceClassName;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kIOUSBHostVMEntitlement;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kIOUSBTransportDextEntitlement;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertyAdditionalFailureInfo;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertyAddtionalInfoURL;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertyAddtionalInfoURLIndex;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertyAltModeFailed;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertyAltModePowerFailed;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertyAlternateMode;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertyAlternateModeString;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertyAlternateModeStringIndex;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertyBcdVersion;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertyConfigured;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertyCurrentMode;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertyModeValueDisplayPort;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertyModeValueThunderbolt;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertyModeValueUSB4;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertyNumberOfAlternateModes;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertyPreferredAlternateMode;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertyPreferredMode;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertySVID;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertyVCONNPower;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertyVersion;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostBillboardDevicePropertydwAlternateModeVdo;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertyCompanion;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertyCompanionControllerName;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertyControlRequestPolicy;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertyDeferRegisterService;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertyFullSpeedCompanion;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertyHighSpeedCompanion;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertyInterruptRMBS;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertyIsochronousRMBS;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertyIsochronousRequiresContiguous;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertyLowSpeedCompanion;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertyPersistFullSpeedIsochronous;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertyPortWakeSourcesPolicy;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertyProtocolRevision;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertyRTD3Supported;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertySleepSupported;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertySoftRetryPolicy;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertyStreamPolicy;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertySuperSpeedCompanion;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertyTierLimit;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertyUSB2LPMPolicy;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertyUSB3LPMPolicy;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostControllerPropertyUSB4LPMPolicy;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDescriptorOverrideProductStringIndex;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDescriptorOverrideSerialNumberStringIndex;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDescriptorOverrideVendorStringIndex;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyAddress;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyConfigurationCurrentOverride;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyConfigurationDescriptorOverride;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyContainerID;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyCurrentConfiguration;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyDescriptorOverride;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyDesiredChargingCurrent;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyDeviceDescriptorOverride;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyDeviceECID;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyDeviceUDID;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyDisablePortLPM;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyEnableLPM;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyEnumerationState;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyFailedRequestedPower;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyIdlePolicy;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyManufacturerStringIndex;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyMaxPacketSize;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyNumConfigs;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyPowerSinkAllocation;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyPowerSinkCapability;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyPreferredConfiguration;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyPreferredRecoveryConfiguration;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyProductString;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyProductStringIndex;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyRemoteWakeOverride;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyResetDurationOverride;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyResumeRecoveryTime;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertySerialNumberString;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertySerialNumberStringIndex;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertySignature;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyStandardVersion;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyStreamsSupported;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyTunnel;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyUSB3Preferred;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyUSB3Required;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostDevicePropertyVendorString;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostHubPropertyHubPowerSupplyType;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostHubPropertyIdlePolicy;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostHubPropertyPortSequenceDelay;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostHubPropertyPowerSupply;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostHubPropertyStartupDelay;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostInterfacePropertyAlternateSetting;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostInterfacePropertyNumEndpoints;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostInterfacePropertyString;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostInterfacePropertyStringIndex;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostMatchingPropertyConfigurationValue;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostMatchingPropertyDeviceClass;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostMatchingPropertyDeviceProtocol;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostMatchingPropertyDeviceReleaseNumber;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostMatchingPropertyDeviceReleaseNumberRange;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostMatchingPropertyDeviceSubClass;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostMatchingPropertyInterfaceClass;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostMatchingPropertyInterfaceNumber;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostMatchingPropertyInterfaceProtocol;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostMatchingPropertyInterfaceSubClass;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostMatchingPropertyPortType;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostMatchingPropertyProductID;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostMatchingPropertyProductIDArray;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostMatchingPropertyProductIDMask;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostMatchingPropertySpeed;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostMatchingPropertyVendorID;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyBusCurrentAllocation;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyBusCurrentSleepAllocation;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyCardReader;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyCardReaderValidateDescriptors;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyCompanionIndex;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyCompanionPortNumber;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyConnectable;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyConnectorType;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyDisconnectInterval;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyExternalDevicePowerController;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyExternalDeviceResetController;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyIOPortServicePath;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyLinkSpeedLimit;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyOvercurrent;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyPortNumber;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyPowerSource;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyProtocolCompanionRevision1;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyProtocolCompanionRevision2;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyProtocolCompanionRevision3;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyProtocolRevision1;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyProtocolRevision2;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyProtocolRevision3;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyRemovable;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertySimulateInterrupt;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyStatus;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyTestMode;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyUSB3Mode;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyUsb3ComplianceMode;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPortPropertyUsbCPortNumber;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPropertyAllowSoftRetry;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPropertyBusCurrentPoolID;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPropertyDebugOptions;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPropertyExclusiveOwner;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPropertyFailedRemoteWake;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPropertyForceHardwareException;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPropertyForceLinkSpeed;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPropertyForcePower;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPropertyLocationID;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPropertySleepPortCurrentLimit;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPropertySleepPowerSupply;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPropertySmcBusCurrentPoolID;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPropertyWakePortCurrentLimit;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostPropertyWakePowerSupply;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostUserClientPropertyBufferAllocations;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostUserClientPropertyBufferStatistics;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostUserClientPropertyEnableDataToggleReset;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostUserClientPropertyEnableReset;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostUserClientPropertyEntitlement;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostUserClientPropertyEntitlementExceptionAllowUnlocked;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::kUSBHostUserClientPropertyEntitlementRequired;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::tIOUSBHostConnectionSpeed;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::tIOUSBHostPortStatus;
#[cfg(feature = "IOUSBHostFamilyDefinitions")]
pub use self::__IOUSBHostFamilyDefinitions::tIOUSBHostPortType;
#[cfg(feature = "IOUSBLib")]
pub use self::__IOUSBLib::kIOUSBDeviceClassName;
#[cfg(feature = "IOUSBLib")]
pub use self::__IOUSBLib::kIOUSBInterfaceClassName;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceInterface;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceInterface100;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceInterface182;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceInterface187;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceInterface197;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceInterface245;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceInterface300;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceInterface320;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceInterface400;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceInterface500;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceInterface650;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceInterface942;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceStruct100;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceStruct182;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceStruct187;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceStruct197;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceStruct245;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceStruct300;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceStruct320;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceStruct400;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceStruct500;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceStruct650;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBDeviceStruct942;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceInterface;
#[cfg(all(feature = "IOUSBLib", feature = "USB", feature = "libc"))]
pub use self::__IOUSBLib::IOUSBInterfaceInterface100;
#[cfg(all(feature = "IOUSBLib", feature = "USB", feature = "libc"))]
pub use self::__IOUSBLib::IOUSBInterfaceInterface182;
#[cfg(all(feature = "IOUSBLib", feature = "USB", feature = "libc"))]
pub use self::__IOUSBLib::IOUSBInterfaceInterface183;
#[cfg(all(feature = "IOUSBLib", feature = "USB", feature = "libc"))]
pub use self::__IOUSBLib::IOUSBInterfaceInterface190;
#[cfg(all(feature = "IOUSBLib", feature = "USB", feature = "libc"))]
pub use self::__IOUSBLib::IOUSBInterfaceInterface192;
#[cfg(all(feature = "IOUSBLib", feature = "USB", feature = "libc"))]
pub use self::__IOUSBLib::IOUSBInterfaceInterface197;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceInterface220;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceInterface245;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceInterface300;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceInterface398;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceInterface400;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceInterface500;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceInterface550;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceInterface650;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceInterface700;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceInterface800;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceInterface942;
#[cfg(all(feature = "IOUSBLib", feature = "USB", feature = "libc"))]
pub use self::__IOUSBLib::IOUSBInterfaceStruct100;
#[cfg(all(feature = "IOUSBLib", feature = "USB", feature = "libc"))]
pub use self::__IOUSBLib::IOUSBInterfaceStruct182;
#[cfg(all(feature = "IOUSBLib", feature = "USB", feature = "libc"))]
pub use self::__IOUSBLib::IOUSBInterfaceStruct183;
#[cfg(all(feature = "IOUSBLib", feature = "USB", feature = "libc"))]
pub use self::__IOUSBLib::IOUSBInterfaceStruct190;
#[cfg(all(feature = "IOUSBLib", feature = "USB", feature = "libc"))]
pub use self::__IOUSBLib::IOUSBInterfaceStruct192;
#[cfg(all(feature = "IOUSBLib", feature = "USB", feature = "libc"))]
pub use self::__IOUSBLib::IOUSBInterfaceStruct197;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceStruct220;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceStruct245;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceStruct300;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceStruct398;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceStruct400;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceStruct500;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceStruct550;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceStruct650;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceStruct700;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceStruct800;
#[cfg(all(
    feature = "AppleUSBDefinitions",
    feature = "IOUSBLib",
    feature = "USB",
    feature = "libc"
))]
pub use self::__IOUSBLib::IOUSBInterfaceStruct942;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kAppleVendorID;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kHIDBootProtocolValue;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kHIDKeyboardInterfaceProtocol;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kHIDMouseInterfaceProtocol;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kHIDNoInterfaceProtocol;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kHIDReportProtocolValue;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kHIDRqGetIdle;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kHIDRqGetProtocol;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kHIDRqGetReport;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kHIDRqSetIdle;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kHIDRqSetProtocol;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kHIDRqSetReport;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kHIDRtFeatureReport;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kHIDRtInputReport;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kHIDRtOutputReport;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kHubSuperSpeedProtocol;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kMSCProtocolBulkOnly;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kMSCProtocolControlBulk;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kMSCProtocolControlBulkInterrupt;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kMSCProtocolUSBAttachedSCSI;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSB100mA;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSB100mAAvailable;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSB1284DeviceID;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSB150mA;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSB150mAAvailable;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSB20ExtensionLPMSupported;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSB2ComplianceDeviceProtocol;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSB2MaxPowerPerPort;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSB3HUBDesc;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSB3MaxPowerPerPort;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSB500mAAvailable;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSB900mAAvailable;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBATMNetworkingSubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBAdaptiveIsocSyncType;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBAlternateSetting;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBAnyDesc;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBAnyDirn;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBAnyType;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBApplicationSpecificClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBApplicationSpecificInterfaceClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBAsynchronousIsocSyncType;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBAtrBusPowered;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBAtrRemoteWakeup;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBAtrSelfPowered;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBAudioClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBAudioControlSubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBAudioInterfaceClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBAudioStreamingSubClass;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBBOSDescriptor;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBBillBoardClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBBillboardAdditinalInfoNoPower;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBBillboardAdditinalInfoNoUSBPD;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBBillboardAltModeConfigSuccess;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBBillboardConfigNotAttempted;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBBillboardConfigUnsuccessful;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBBillboardUnspecifiedError;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBBillboardVConn1P5Watt;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBBillboardVConn1Watt;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBBillboardVConn2Watt;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBBillboardVConn3Watt;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBBillboardVConn4Watt;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBBillboardVConn5Watt;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBBillboardVConn6Watt;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBBillboardVConnNoPowerReq;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBBillboardVConnReserved;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBBluetoothProgrammingInterfaceProtocol;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBBulk;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBCapsLockKey;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBChipSmartCardInterfaceClass;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBCommAbstractSubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBCommCAPISubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBCommClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBCommDirectLineSubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBCommEthernetNetworkingSubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBCommMultiChannelSubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBCommTelephoneSubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBCommonClassSubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBCommunicationClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBCommunicationControlInterfaceClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBCommunicationDataInterfaceClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBCompatibilityMatch;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBCompositeClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBCompositeSubClass;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBConfDesc;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBConfigurationValue;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBContainerID;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBContentSecurityInterfaceClass;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBControl;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBDFUAttributesMask;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBDFUCanDownloadBit;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBDFUCanUploadBit;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBDFUManifestationTolerantBit;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBDFUSubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBDataClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBDataIsocUsageType;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBDevice;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBDeviceCapability;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBDeviceCapabilityBillboard;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBDeviceCapabilityBillboardAltMode;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBDeviceCapabilityContainerID;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBDeviceCapabilitySuperSpeedUSB;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBDeviceCapabilityUSB20Extension;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBDeviceCapabilityWirelessUSB;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBDeviceClass;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBDeviceDesc;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBDeviceMaxPacketSize;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBDeviceNumConfigs;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBDeviceProtocol;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBDeviceQualifierDesc;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBDeviceReleaseNumber;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBDeviceSubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBDiagnosticClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBDiagnosticDeviceInterfaceClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBDisplayClass;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBEndpoint;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBEndpointDesc;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBEndpointDirectionIn;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBEndpointDirectionOut;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBEndpointbmAttributesSynchronizationTypeMask;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBEndpointbmAttributesSynchronizationTypeShift;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBEndpointbmAttributesTransferTypeMask;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBEndpointbmAttributesUsageTypeMask;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBEndpointbmAttributesUsageTypeShift;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBFeatureDeviceRemoteWakeup;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBFeatureEndpointStall;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBFeatureFunctionSuspend;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBFeatureLTMEnable;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBFeatureTestMode;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBFeatureU1Enable;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBFeatureU2Enable;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBFeedbackIsocUsageType;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBFunctionRemoteWakeCapableBit;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBFunctionRemoteWakeEnableBit;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBFunctionRemoteWakeupBit;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBHIDBootInterfaceSubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBHIDClass;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBHIDDesc;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBHIDInterfaceClass;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBHUBDesc;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBHubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBHubSubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBImageInterfaceClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBImplicitFeedbackDataIsocUsageType;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBIn;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBInterface;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBInterfaceAssociationDesc;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBInterfaceClass;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBInterfaceDesc;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBInterfaceNumber;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBInterfacePowerDesc;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBInterfaceProtocol;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBInterfaceString;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBInterfaceStringIndex;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBInterfaceSubClass;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBInterrupt;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBIrDABridgeSubClass;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBIsoc;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBLowPowerSuspendStateBit;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBMIDIStreamingSubClass;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBManufacturerStringIndex;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBMassStorageATAPISubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBMassStorageClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBMassStorageInterfaceClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBMassStorageQIC157SubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBMassStorageRBCSubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBMassStorageSCSISubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBMassStorageSFF8070iSubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBMassStorageUFISubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBMiscellaneousClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBNoSynchronizationIsocSyncType;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBNone;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBNotificationInterruptUsageType;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBNumEndpoints;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBNumLockKey;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBOnTheGoDesc;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBOther;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBOtherSpeedConfDesc;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBOut;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBPeriodicInterruptUsageType;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBPersonalHealthcareClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBPersonalHealthcareInterfaceClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBPhysicalDesc;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBPhysicalInterfaceClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBPrintingClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBPrintingInterfaceClass;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBProductID;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBProductName;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBProductString;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBProductStringIndex;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBRFControllerSubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBRel10;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBRel11;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBRel20;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBRel30;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBReportDesc;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBReprogrammableDiagnosticSubClass;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBRqClearFeature;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBRqGetConfig;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBRqGetDescriptor;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBRqGetInterface;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBRqGetState;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBRqGetStatus;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBRqReserved2;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBRqSetAddress;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBRqSetConfig;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBRqSetDescriptor;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBRqSetFeature;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBRqSetInterface;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBRqSyncFrame;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBScrollLockKey;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBSerialNumberString;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBSerialNumberStringIndex;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBSetIsochDelay;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBSetSel;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBSpecReleaseNumber;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBStandard;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBStandardVersion;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBStringDesc;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBSuperSpeedEndpointCompanion;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBSuperSpeedLTMCapable;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBSuperSpeedSupportsFS;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBSuperSpeedSupportsHS;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBSuperSpeedSupportsLS;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBSuperSpeedSupportsSS;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBSynchronousIsocSyncType;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBTestMeasurementSubClass;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBVendor;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBVendorID;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBVendorName;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBVendorSpecificClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBVendorSpecificInterfaceClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBVendorSpecificProtocol;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBVendorString;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBVideoControlSubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBVideoInterfaceClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBVideoInterfaceCollectionSubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBVideoStreamingSubClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBWirelessControllerClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBWirelessControllerInterfaceClass;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSBbEndpointAddressMask;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBbEndpointDirectionBit;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSBbEndpointDirectionMask;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USBSpec"))]
pub use self::__USBSpec::kUSDebugDesc;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSPrintingClassGePortStatus;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSPrintingClassGetDeviceID;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::kUSPrintingClassSoftReset;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::KUSBInterfaceAssociationDescriptorProtocol;
#[cfg(feature = "USBSpec")]
pub use self::__USBSpec::USBClassSpecificDesc;
#[cfg(feature = "USB")]
pub use self::__USB::addPacketShift;
#[cfg(feature = "USB")]
pub use self::__USB::kAppleAcpiRootHubDepth;
#[cfg(feature = "USB")]
pub use self::__USB::kAppleCurrentAvailable;
#[cfg(feature = "USB")]
pub use self::__USB::kAppleCurrentInSleep;
#[cfg(feature = "USB")]
pub use self::__USB::kAppleExternalSuperSpeedPorts;
#[cfg(feature = "USB")]
pub use self::__USB::kAppleInternalUSBDevice;
#[cfg(feature = "USB")]
pub use self::__USB::kApplePortCurrentInSleep;
#[cfg(feature = "USB")]
pub use self::__USB::kApplePowerSupply;
#[cfg(feature = "USB")]
pub use self::__USB::kAppleRevocableExtraCurrent;
#[cfg(feature = "USB")]
pub use self::__USB::kAppleStandardPortCurrentInSleep;
#[cfg(feature = "USB")]
pub use self::__USB::kAppleUnconnectedSuperSpeedPorts;
#[cfg(feature = "USB")]
pub use self::__USB::kCallInterfaceOpenWithGate;
#[cfg(all(feature = "USB", feature = "USBSpec"))]
pub use self::__USB::kClearDeviceFeature;
#[cfg(all(feature = "USB", feature = "USBSpec"))]
pub use self::__USB::kClearEndpointFeature;
#[cfg(all(feature = "USB", feature = "USBSpec"))]
pub use self::__USB::kClearInterfaceFeature;
#[cfg(feature = "USB")]
pub use self::__USB::kConfigurationDescriptorOverride;
#[cfg(feature = "USB")]
pub use self::__USB::kEHCIIsochMaxBusStall;
#[cfg(all(feature = "USB", feature = "USBSpec"))]
pub use self::__USB::kGetConfiguration;
#[cfg(all(feature = "USB", feature = "USBSpec"))]
pub use self::__USB::kGetDescriptor;
#[cfg(all(feature = "USB", feature = "USBSpec"))]
pub use self::__USB::kGetDeviceStatus;
#[cfg(all(feature = "USB", feature = "USBSpec"))]
pub use self::__USB::kGetEndpointStatus;
#[cfg(all(feature = "USB", feature = "USBSpec"))]
pub use self::__USB::kGetInterface;
#[cfg(all(feature = "USB", feature = "USBSpec"))]
pub use self::__USB::kGetInterfaceStatus;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBAnyClass;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBAnyProduct;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBAnyProtocol;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBAnySubClass;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBAnyVendor;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBBitstufErr;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBBufferOverrunErr;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBBufferUnderrunErr;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBCRCErr;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBClearPipeStallNotRecursive;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBConfigNotFound;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBDataToggleErr;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBDeviceCapabilityDescriptorLengthMin;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBDeviceCapabilityDescriptorType;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBDeviceCountExceeded;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBDeviceNotHighSpeed;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBDevicePortWasNotSuspended;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBDeviceTransferredToCompanion;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBEndpointCountExceeded;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBEndpointNotFound;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBFindInterfaceDontCare;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBHighSpeedSplitError;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBInterfaceNotFound;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBInvalidSSEndpoint;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBLinkErr;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBLowLatencyBufferNotPreviouslyAllocated;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBLowLatencyFrameListNotPreviouslyAllocated;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageCompositeDriverReconfigured;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageConfigurationSet;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageController;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageDeviceCountExceeded;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageEndpointCountExceeded;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageExpressCardCantWake;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageFromThirdParty;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageHubCountExceeded;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageHubIsDeviceConnected;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageHubIsPortEnabled;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageHubPortClearTT;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageHubPortDeviceDisconnected;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageHubReEnumeratePort;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageHubResetPort;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageHubResumePort;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageHubSetPortRecoveryTime;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageHubSuspendPort;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageLegacyReEnumerateDevice;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageLegacyResetDevice;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageLegacySuspendDevice;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageNotEnoughPower;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageOvercurrentCondition;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessagePortHasBeenReset;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessagePortHasBeenResumed;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessagePortHasBeenSuspended;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessagePortWasNotSuspended;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageReallocateExtraCurrent;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageReleaseExtraCurrent;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageRootHubWakeEvent;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageTDMLowBattery;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBMessageUnsupportedConfiguration;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBNoAsyncPortErr;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBNotEnoughPipesErr;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBNotEnoughPowerErr;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBNotSent1Err;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBNotSent2Err;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBPIDCheckErr;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBPipeStalled;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBPortWasSuspended;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBReserved1Err;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBReserved2Err;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBStreamsNotSupported;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBSyncRequestOnWLThread;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBTooManyPipesErr;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBTooManyTransactionsPending;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBTransactionReturned;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBTransactionTimeout;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBUnknownPipeErr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::kIOUSBVendorIDApple;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::kIOUSBVendorIDAppleComputer;
#[cfg(feature = "USB")]
pub use self::__USB::kIOUSBWrongPIDErr;
#[cfg(feature = "USB")]
pub use self::__USB::kMaxBusStall10uS;
#[cfg(feature = "USB")]
pub use self::__USB::kMaxBusStall25uS;
#[cfg(feature = "USB")]
pub use self::__USB::kOHCIIsochMaxBusStall;
#[cfg(feature = "USB")]
pub use self::__USB::kOverrideAllowLowPower;
#[cfg(feature = "USB")]
pub use self::__USB::kOverrideAttachedToCPU;
#[cfg(feature = "USB")]
pub use self::__USB::kOverrideIfAtLocationID;
#[cfg(all(feature = "USB", feature = "USBSpec"))]
pub use self::__USB::kSetAddress;
#[cfg(all(feature = "USB", feature = "USBSpec"))]
pub use self::__USB::kSetConfiguration;
#[cfg(all(feature = "USB", feature = "USBSpec"))]
pub use self::__USB::kSetDescriptor;
#[cfg(all(feature = "USB", feature = "USBSpec"))]
pub use self::__USB::kSetDeviceFeature;
#[cfg(all(feature = "USB", feature = "USBSpec"))]
pub use self::__USB::kSetEndpointFeature;
#[cfg(all(feature = "USB", feature = "USBSpec"))]
pub use self::__USB::kSetInterface;
#[cfg(all(feature = "USB", feature = "USBSpec"))]
pub use self::__USB::kSetInterfaceFeature;
#[cfg(feature = "USB")]
pub use self::__USB::kSuperSpeedBusBitMask;
#[cfg(all(feature = "USB", feature = "USBSpec"))]
pub use self::__USB::kSyncFrame;
#[cfg(feature = "USB")]
pub use self::__USB::kUHCIIsochMaxBusStall;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBAddress_Mask;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBAddress_Shift;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBBusID;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBCTBNotEnoughPowerNotificationType;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBCTBUnsupportedNotificationType;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBCUnsupportedTBCableNotificationType;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBCUnsupportedTBPortNotificationType;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBConnectable;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBControllerNeedsContiguousMemoryForIsoch;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USB"))]
pub use self::__USB::kUSBControllerSleepSupported;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBDefaultControlCompletionTimeoutMS;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBDefaultControlNoDataTimeoutMS;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USB"))]
pub use self::__USB::kUSBDeviceConfigurationCurrentOverride;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBDeviceCountExceededNotificationType;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USB"))]
pub use self::__USB::kUSBDeviceCurrentConfiguration;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USB"))]
pub use self::__USB::kUSBDeviceFailedRequestedPower;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBDeviceIDMask;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBDeviceIDShift;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBDeviceMask;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBDevicePropertyAddress;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBDevicePropertyBusPowerAvailable;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USB"))]
pub use self::__USB::kUSBDevicePropertyLocationID;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBDevicePropertySpeed;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USB"))]
pub use self::__USB::kUSBDeviceRemoteWakeOverride;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USB"))]
pub use self::__USB::kUSBDeviceResetDurationOverride;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USB"))]
pub use self::__USB::kUSBDeviceResumeRecoveryTime;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBDeviceSpeedFull;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBDeviceSpeedHigh;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBDeviceSpeedLow;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBDeviceSpeedSuper;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBDeviceSpeedSuperPlus;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBDeviceSpeedSuperPlusBy2;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBEndPtShift;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBEndpointCountExceededNotificationType;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBEndpointPropertiesVersion3;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBEndpointTransferTypeUCMask;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBExpressCardCantWake;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBFullSpeedMicrosecondsInFrame;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBGangOverCurrentNotificationType;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBHighSpeedMicrosecondsInFrame;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBHostConnectorType;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBHubCountExceededNotificationType;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBHubDontAllowLowPower;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USB"))]
pub use self::__USB::kUSBHubPropertyPowerSupply;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBIndividualOverCurrentNotificationType;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBInterfaceIDMask;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBInterfaceIDShift;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBLowLatencyIsochTransferKey;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBMaxDevice;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBMaxDevices;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBMaxFSIsocEndpointReqCount;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBMaxHSIsocEndpointReqCount;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBMaxHSIsocFrameCount;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBMaxInterfaces;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBMaxPipes;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBMaxStream;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBNoPipeIdx;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBNoStream;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBNoUserNotificationType;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBNotEnoughPowerNoACNotificationType;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBNotEnoughPowerNotificationType;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBNotificationPostForcedResumeBit;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBNotificationPostForcedSuspendBit;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBNotificationPreForcedResumeBit;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBNotificationPreForcedSuspendBit;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBOutOfSpecMPSOK;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBPRimeStream;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBPipeIDMask;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USB"))]
pub use self::__USB::kUSBPortPropertyBusCurrentAllocation;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBPreferredConfiguration;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBPreferredInterface;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBPreferredInterfacePriority;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USB"))]
pub use self::__USB::kUSBProductIDMask;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USB"))]
pub use self::__USB::kUSBProductIdsArrayName;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USB"))]
pub use self::__USB::kUSBPropertyDebugLevel;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USB"))]
pub use self::__USB::kUSBPropertyRemovable;
#[cfg(all(feature = "IOUSBHostFamilyDefinitions", feature = "USB"))]
pub use self::__USB::kUSBPropertyTestMode;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBRqDirnMask;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::kUSBRqDirnShift;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::kUSBRqRecipientMask;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBRqTypeMask;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::kUSBRqTypeShift;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBSpeed_Mask;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBSpeed_Shift;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBStream0;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBStreamIDAllStreamsMask;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBStreamIDMask;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBSuspendPort;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBTDMLowBatteryType;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBTooManyDevicesAddress;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBUCRequestWithoutUSBNotificationMask;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBUnsupportedNotificationType;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBUserClientEntitlementRequired;
#[cfg(feature = "USB")]
pub use self::__USB::kUSB_EPDesc_MaxMPS;
#[cfg(feature = "USB")]
pub use self::__USB::kUSB_EPDesc_bmAttributes_SyncType_Mask;
#[cfg(feature = "USB")]
pub use self::__USB::kUSB_EPDesc_bmAttributes_SyncType_Shift;
#[cfg(feature = "USB")]
pub use self::__USB::kUSB_EPDesc_bmAttributes_TranType_Mask;
#[cfg(feature = "USB")]
pub use self::__USB::kUSB_EPDesc_bmAttributes_TranType_Shift;
#[cfg(feature = "USB")]
pub use self::__USB::kUSB_EPDesc_bmAttributes_UsageType_Mask;
#[cfg(feature = "USB")]
pub use self::__USB::kUSB_EPDesc_bmAttributes_UsageType_Shift;
#[cfg(feature = "USB")]
pub use self::__USB::kUSB_EPDesc_wMaxPacketSize_MPS_Mask;
#[cfg(feature = "USB")]
pub use self::__USB::kUSB_EPDesc_wMaxPacketSize_MPS_Shift;
#[cfg(feature = "USB")]
pub use self::__USB::kUSB_HSFSEPDesc_wMaxPacketSize_Mult_Mask;
#[cfg(feature = "USB")]
pub use self::__USB::kUSB_HSFSEPDesc_wMaxPacketSize_Mult_Shift;
#[cfg(feature = "USB")]
pub use self::__USB::kUSB_SSCompDesc_Bulk_MaxStreams_Mask;
#[cfg(feature = "USB")]
pub use self::__USB::kUSB_SSCompDesc_Bulk_MaxStreams_Shift;
#[cfg(feature = "USB")]
pub use self::__USB::kUSB_SSCompDesc_Isoc_Mult_Mask;
#[cfg(feature = "USB")]
pub use self::__USB::kUSB_SSCompDesc_Isoc_Mult_Shift;
#[cfg(feature = "USB")]
pub use self::__USB::kUSBiOSDeviceNotEnoughPowerNotificationType;
#[cfg(feature = "USB")]
pub use self::__USB::kXHCIIsochMaxBusStall;
#[cfg(feature = "USB")]
pub use self::__USB::kXHCISSRootHubAddress;
#[cfg(feature = "USB")]
pub use self::__USB::kXHCIUSB2RootHubAddress;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBBOSDescriptorPtr;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBBulkPipeReq;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBCompletion;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBCompletionAction;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBCompletionActionWithTimeStamp;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBCompletionWithTimeStamp;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBConfigurationDescHeaderPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBConfigurationDescriptorPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBDFUDescriptorPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBDescriptorHeaderPtr;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBDevReqOOL;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBDevReqOOLTO;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBDevRequest;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBDevRequestTO;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBDeviceCapabilityBillboardAltConfigPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBDeviceCapabilityBillboardAltModePtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBDeviceCapabilityBillboardPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBDeviceCapabilityContainerIDPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBDeviceCapabilityDescriptorHeaderPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBDeviceCapabilitySuperSpeedPlusUSBPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBDeviceCapabilitySuperSpeedUSBPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBDeviceCapabilityUSB2ExtensionPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBDeviceDescriptorPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBDeviceQualifierDescriptorPtr;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBDeviceRequestPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBEndpointDescriptorPtr;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBEndpointProperties;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBEndpointPropertiesPtr;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBFindEndpointRequest;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBFindInterfaceRequest;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBGetFrameStruct;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBHIDData;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBHIDDataPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBHIDDescriptorPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBHIDReportDescPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBInterfaceAssociationDescriptorPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBInterfaceDescriptorPtr;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBIsocCompletion;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBIsocCompletionAction;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBIsocFrame;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBIsocStruct;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBKeyboardData;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBKeyboardDataPtr;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBLowLatencyIsocCompletion;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBLowLatencyIsocCompletionAction;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBLowLatencyIsocFrame;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBLowLatencyIsocStruct;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBMatch;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBMouseData;
#[cfg(feature = "USB")]
pub use self::__USB::IOUSBMouseDataPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBPlatformCapabilityDescriptorPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBStringDescriptorPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBSuperSpeedEndpointCompanionDescriptorPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::IOUSBSuperSpeedPlusIsochronousEndpointCompanionDescriptorPtr;
#[cfg(all(feature = "AppleUSBDefinitions", feature = "USB"))]
pub use self::__USB::UASPipeDescriptorPtr;
#[cfg(feature = "USB")]
pub use self::__USB::USBDeviceAddress;
#[cfg(feature = "USB")]
pub use self::__USB::USBDeviceInformationBits;
#[cfg(feature = "USB")]
pub use self::__USB::USBLowLatencyBufferType;
#[cfg(feature = "USB")]
pub use self::__USB::USBNotificationTypes;
#[cfg(feature = "USB")]
pub use self::__USB::USBPhysicalAddress32;
#[cfg(feature = "USB")]
pub use self::__USB::USBPowerRequestTypes;
#[cfg(feature = "USB")]
pub use self::__USB::USBReEnumerateOptions;
#[cfg(feature = "USB")]
pub use self::__USB::USBStatus;
#[cfg(feature = "USB")]
pub use self::__USB::USBStatusPtr;
